﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace CalcHelper
{
    public partial class Form1 : Form
    {
        /*
         *  Compliments of Joe Argiro: Sorting a List<string> of boxes proved to be a bigger challenge
         *  than doing it in Ruby [usual case]. We are implementing the Compare() method of IComparer
         *  interface, where we override the Compare method to sort based on Page and Box numbers
         *  expressed as integers. This is an ascending sort.
         *
         *  We use this by passing the reference of this class as an object parameter to Sort() like this example:
         *  
         *  List<string> boxList = new List<string> { "box1_2", "box5_1", "box1_10", "box1_5" };
         *  
         *  boxList.Sort(new BoxCompare());
        */
        public class BoxCompare : IComparer<string>
        {
            public int Compare(string p1, string p2)
            {
                int page1 = 0;
                int box1 = 0;

                int page2 = 0;
                int box2 = 0;

                int.TryParse(p1.Substring(3, p1.Substring(3).IndexOf('_')), out page1);
                int.TryParse(p1.Substring(p1.IndexOf('_') + 1), out box1);

                int.TryParse(p2.Substring(3, p2.Substring(3).IndexOf('_')), out page2);
                int.TryParse(p2.Substring(p2.IndexOf('_') + 1), out box2);

                if (page1 == page2)
                {
                    if (box1 == box2)
                        return 0;
                    else if (box1 < box2)
                        return -1;
                    else
                        return 1;
                }
                else if (page1 < page2)
                {
                    return -1;
                }
                else
                    return 1;
            }
        }
    }
}